==> kubernetes-model-core-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/ISCSIVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ISCSIVolumeSourceFluent<A extends ISCSIVolumeSourceFluent<A>> extends Fluent<A> {


    public Boolean getChapAuthDiscovery();
    public A withChapAuthDiscovery(Boolean chapAuthDiscovery);
    public Boolean hasChapAuthDiscovery();
    public A withNewChapAuthDiscovery(String arg1);
    public A withNewChapAuthDiscovery(boolean arg1);
    public Boolean getChapAuthSession();
    public A withChapAuthSession(Boolean chapAuthSession);
    public Boolean hasChapAuthSession();
    public A withNewChapAuthSession(String arg1);
    public A withNewChapAuthSession(boolean arg1);
    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    public String getInitiatorName();
    public A withInitiatorName(String initiatorName);
    public Boolean hasInitiatorName();
    public A withNewInitiatorName(StringBuilder arg1);
    public A withNewInitiatorName(int[] arg1,int arg2,int arg3);
    public A withNewInitiatorName(char[] arg1);
    public A withNewInitiatorName(StringBuffer arg1);
    public A withNewInitiatorName(byte[] arg1,int arg2);
    public A withNewInitiatorName(byte[] arg1);
    public A withNewInitiatorName(char[] arg1,int arg2,int arg3);
    public A withNewInitiatorName(byte[] arg1,int arg2,int arg3);
    public A withNewInitiatorName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewInitiatorName(String arg1);
    public String getIqn();
    public A withIqn(String iqn);
    public Boolean hasIqn();
    public A withNewIqn(StringBuilder arg1);
    public A withNewIqn(int[] arg1,int arg2,int arg3);
    public A withNewIqn(char[] arg1);
    public A withNewIqn(StringBuffer arg1);
    public A withNewIqn(byte[] arg1,int arg2);
    public A withNewIqn(byte[] arg1);
    public A withNewIqn(char[] arg1,int arg2,int arg3);
    public A withNewIqn(byte[] arg1,int arg2,int arg3);
    public A withNewIqn(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewIqn(String arg1);
    public String getIscsiInterface();
    public A withIscsiInterface(String iscsiInterface);
    public Boolean hasIscsiInterface();
    public A withNewIscsiInterface(StringBuilder arg1);
    public A withNewIscsiInterface(int[] arg1,int arg2,int arg3);
    public A withNewIscsiInterface(char[] arg1);
    public A withNewIscsiInterface(StringBuffer arg1);
    public A withNewIscsiInterface(byte[] arg1,int arg2);
    public A withNewIscsiInterface(byte[] arg1);
    public A withNewIscsiInterface(char[] arg1,int arg2,int arg3);
    public A withNewIscsiInterface(byte[] arg1,int arg2,int arg3);
    public A withNewIscsiInterface(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewIscsiInterface(String arg1);
    public Integer getLun();
    public A withLun(Integer lun);
    public Boolean hasLun();
    public A withNewLun(int arg1);
    public A addToPortals(int index,String item);
    public A setToPortals(int index,String item);
    public A addToPortals(String... items);
    public A addAllToPortals(Collection<String> items);
    public A removeFromPortals(String... items);
    public A removeAllFromPortals(Collection<String> items);
    public List<String> getPortals();
    public String getPortal(int index);
    public String getFirstPortal();
    public String getLastPortal();
    public String getMatchingPortal(Predicate<String> predicate);
    public Boolean hasMatchingPortal(Predicate<String> predicate);
    public A withPortals(List<String> portals);
    public A withPortals(String... portals);
    public Boolean hasPortals();
    public A addNewPortal(StringBuilder arg1);
    public A addNewPortal(int[] arg1,int arg2,int arg3);
    public A addNewPortal(char[] arg1);
    public A addNewPortal(StringBuffer arg1);
    public A addNewPortal(byte[] arg1,int arg2);
    public A addNewPortal(byte[] arg1);
    public A addNewPortal(char[] arg1,int arg2,int arg3);
    public A addNewPortal(byte[] arg1,int arg2,int arg3);
    public A addNewPortal(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewPortal(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public LocalObjectReference getSecretRef();
    public LocalObjectReference buildSecretRef();
    public A withSecretRef(LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public A withNewSecretRef(String name);
    public ISCSIVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public ISCSIVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item);
    public ISCSIVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public ISCSIVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public ISCSIVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item);
    public String getTargetPortal();
    public A withTargetPortal(String targetPortal);
    public Boolean hasTargetPortal();
    public A withNewTargetPortal(StringBuilder arg1);
    public A withNewTargetPortal(int[] arg1,int arg2,int arg3);
    public A withNewTargetPortal(char[] arg1);
    public A withNewTargetPortal(StringBuffer arg1);
    public A withNewTargetPortal(byte[] arg1,int arg2);
    public A withNewTargetPortal(byte[] arg1);
    public A withNewTargetPortal(char[] arg1,int arg2,int arg3);
    public A withNewTargetPortal(byte[] arg1,int arg2,int arg3);
    public A withNewTargetPortal(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTargetPortal(String arg1);
    public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LocalObjectReferenceFluent<ISCSIVolumeSourceFluent.SecretRefNested<N>> {

            public N and();
            public N endSecretRef();    }


}

==> kubernetes-model-core-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/ISCSIVolumeSourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ISCSIVolumeSourceFluent<A extends ISCSIVolumeSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public Boolean getChapAuthDiscovery();
    public A withChapAuthDiscovery(Boolean chapAuthDiscovery);
    public Boolean hasChapAuthDiscovery();
    public A withNewChapAuthDiscovery(String arg1);
    public A withNewChapAuthDiscovery(boolean arg1);
    public Boolean getChapAuthSession();
    public A withChapAuthSession(Boolean chapAuthSession);
    public Boolean hasChapAuthSession();
    public A withNewChapAuthSession(String arg1);
    public A withNewChapAuthSession(boolean arg1);
    public String getFsType();
    public A withFsType(String fsType);
    public Boolean hasFsType();
    public A withNewFsType(StringBuilder arg1);
    public A withNewFsType(int[] arg1,int arg2,int arg3);
    public A withNewFsType(char[] arg1);
    public A withNewFsType(StringBuffer arg1);
    public A withNewFsType(byte[] arg1,int arg2);
    public A withNewFsType(byte[] arg1);
    public A withNewFsType(char[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3);
    public A withNewFsType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFsType(String arg1);
    public String getInitiatorName();
    public A withInitiatorName(String initiatorName);
    public Boolean hasInitiatorName();
    public A withNewInitiatorName(StringBuilder arg1);
    public A withNewInitiatorName(int[] arg1,int arg2,int arg3);
    public A withNewInitiatorName(char[] arg1);
    public A withNewInitiatorName(StringBuffer arg1);
    public A withNewInitiatorName(byte[] arg1,int arg2);
    public A withNewInitiatorName(byte[] arg1);
    public A withNewInitiatorName(char[] arg1,int arg2,int arg3);
    public A withNewInitiatorName(byte[] arg1,int arg2,int arg3);
    public A withNewInitiatorName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewInitiatorName(String arg1);
    public String getIqn();
    public A withIqn(String iqn);
    public Boolean hasIqn();
    public A withNewIqn(StringBuilder arg1);
    public A withNewIqn(int[] arg1,int arg2,int arg3);
    public A withNewIqn(char[] arg1);
    public A withNewIqn(StringBuffer arg1);
    public A withNewIqn(byte[] arg1,int arg2);
    public A withNewIqn(byte[] arg1);
    public A withNewIqn(char[] arg1,int arg2,int arg3);
    public A withNewIqn(byte[] arg1,int arg2,int arg3);
    public A withNewIqn(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewIqn(String arg1);
    public String getIscsiInterface();
    public A withIscsiInterface(String iscsiInterface);
    public Boolean hasIscsiInterface();
    public A withNewIscsiInterface(StringBuilder arg1);
    public A withNewIscsiInterface(int[] arg1,int arg2,int arg3);
    public A withNewIscsiInterface(char[] arg1);
    public A withNewIscsiInterface(StringBuffer arg1);
    public A withNewIscsiInterface(byte[] arg1,int arg2);
    public A withNewIscsiInterface(byte[] arg1);
    public A withNewIscsiInterface(char[] arg1,int arg2,int arg3);
    public A withNewIscsiInterface(byte[] arg1,int arg2,int arg3);
    public A withNewIscsiInterface(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewIscsiInterface(String arg1);
    public Integer getLun();
    public A withLun(Integer lun);
    public Boolean hasLun();
    public A withNewLun(int arg0);
    public A addToPortals(int index,String item);
    public A setToPortals(int index,String item);
    public A addToPortals(String... items);
    public A addAllToPortals(Collection<String> items);
    public A removeFromPortals(String... items);
    public A removeAllFromPortals(Collection<String> items);
    public List<String> getPortals();
    public String getPortal(int index);
    public String getFirstPortal();
    public String getLastPortal();
    public String getMatchingPortal(Predicate<String> predicate);
    public Boolean hasMatchingPortal(Predicate<String> predicate);
    public A withPortals(List<String> portals);
    public A withPortals(String... portals);
    public Boolean hasPortals();
    public A addNewPortal(StringBuilder arg1);
    public A addNewPortal(int[] arg1,int arg2,int arg3);
    public A addNewPortal(char[] arg1);
    public A addNewPortal(StringBuffer arg1);
    public A addNewPortal(byte[] arg1,int arg2);
    public A addNewPortal(byte[] arg1);
    public A addNewPortal(char[] arg1,int arg2,int arg3);
    public A addNewPortal(byte[] arg1,int arg2,int arg3);
    public A addNewPortal(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewPortal(String arg1);
    public Boolean getReadOnly();
    public A withReadOnly(Boolean readOnly);
    public Boolean hasReadOnly();
    public A withNewReadOnly(String arg1);
    public A withNewReadOnly(boolean arg1);
    
/**
 * This method has been deprecated, please use method buildSecretRef instead.
 * @return The buildable object.
 */
@Deprecated public LocalObjectReference getSecretRef();
    public LocalObjectReference buildSecretRef();
    public A withSecretRef(LocalObjectReference secretRef);
    public Boolean hasSecretRef();
    public A withNewSecretRef(String name);
    public io.fabric8.kubernetes.api.model.ISCSIVolumeSourceFluent.SecretRefNested<A> withNewSecretRef();
    public io.fabric8.kubernetes.api.model.ISCSIVolumeSourceFluent.SecretRefNested<A> withNewSecretRefLike(LocalObjectReference item);
    public io.fabric8.kubernetes.api.model.ISCSIVolumeSourceFluent.SecretRefNested<A> editSecretRef();
    public io.fabric8.kubernetes.api.model.ISCSIVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRef();
    public io.fabric8.kubernetes.api.model.ISCSIVolumeSourceFluent.SecretRefNested<A> editOrNewSecretRefLike(LocalObjectReference item);
    public String getTargetPortal();
    public A withTargetPortal(String targetPortal);
    public Boolean hasTargetPortal();
    public A withNewTargetPortal(StringBuilder arg1);
    public A withNewTargetPortal(int[] arg1,int arg2,int arg3);
    public A withNewTargetPortal(char[] arg1);
    public A withNewTargetPortal(StringBuffer arg1);
    public A withNewTargetPortal(byte[] arg1,int arg2);
    public A withNewTargetPortal(byte[] arg1);
    public A withNewTargetPortal(char[] arg1,int arg2,int arg3);
    public A withNewTargetPortal(byte[] arg1,int arg2,int arg3);
    public A withNewTargetPortal(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewTargetPortal(String arg1);
    public interface SecretRefNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LocalObjectReferenceFluent<io.fabric8.kubernetes.api.model.ISCSIVolumeSourceFluent.SecretRefNested<N>> {

            public N and();
            public N endSecretRef();    }


}
